@@ -1,4 +1,4 @@
-from typing import Dict, List, Mapping, Optional, Tuple, Callable, Any, cast
+from typing import List, Optional, Tuple, Callable, Any, cast
 from pathlib import Path
 from functools import partial
 from spacy.tokens import Doc
@@ -26,14 +26,7 @@ from .pytorch.hf_util import convert_pretrained_model_for_encoder
 from .pytorch.roberta import RobertaConfig, RobertaEncoder
 from .remove_eos_bos import remove_bos_eos
 from .with_non_ws_tokens import with_non_ws_tokens
-from ..tokenization.bbpe_encoder import build_byte_bpe_encoder
-from ..tokenization.sentencepiece_adapters import (
-    build_camembert_adapter,
-    build_xlmr_adapter,
-)
-from ..tokenization.sentencepiece_encoder import build_sentencepiece_encoder
-from ..tokenization.wordpiece_encoder import build_wordpiece_encoder
-from ..tokenization.types import Tok2PiecesModelT, PieceAdapterModelT
+from ..tokenization.types import Tok2PiecesModelT
 from .types import (
     TorchTransformerInT,
     TorchTransformerModelT,
@@ -53,6 +46,7 @@ def build_albert_transformer_model_v1(
         [TorchTransformerModelT],
         SpanExtractorModelT,
     ],
+    piece_encoder: Tok2PiecesModelT,
     attention_probs_dropout_prob: float = 0.0,
     embedding_width: int = 128,
     hidden_act: str = "gelu_new",
@@ -77,6 +71,8 @@ def build_albert_transformer_model_v1(
         Vocabulary size.
     with_spans (Callable):
         Callback that constructs a span generator model.
+    piece_encoder (Model)
+        The piece encoder to segment input tokens.
     attention_probs_dropout_prob (float):
         Dropout probabilty of the self-attention layers.
     embedding_width (int):
@@ -144,8 +140,6 @@ def build_albert_transformer_model_v1(
             grad_scaler_config=grad_scaler_config,
         )
 
-    piece_encoder = build_sentencepiece_encoder()
-
     return build_transformer_model_v1(
         with_spans=with_spans,
         piece_encoder=piece_encoder,
@@ -160,6 +154,7 @@ def build_bert_transformer_model_v1(
         [TorchTransformerModelT],
         SpanExtractorModelT,
     ],
+    piece_encoder: Tok2PiecesModelT,
     attention_probs_dropout_prob: float = 0.1,
     hidden_act: str = "gelu",
     hidden_dropout_prob: float = 0.1,
@@ -182,6 +177,8 @@ def build_bert_transformer_model_v1(
         Vocabulary size.
     with_spans (Callable):
         Callback that constructs a span generator model.
+    piece_encoder (Model)
+        The piece encoder to segment input tokens.
     attention_probs_dropout_prob (float):
         Dropout probabilty of the self-attention layers.
     hidden_act (str):
@@ -243,8 +240,6 @@ def build_bert_transformer_model_v1(
             grad_scaler_config=grad_scaler_config,
         )
 
-    piece_encoder = build_wordpiece_encoder()
-
     return build_transformer_model_v1(
         with_spans=with_spans,
         piece_encoder=piece_encoder,
@@ -259,6 +254,7 @@ def build_camembert_transformer_model_v1(
         [TorchTransformerModelT],
         SpanExtractorModelT,
     ],
+    piece_encoder: Tok2PiecesModelT,
     attention_probs_dropout_prob: float = 0.1,
     hidden_act: str = "gelu",
     hidden_dropout_prob: float = 0.1,
@@ -279,6 +275,8 @@ def build_camembert_transformer_model_v1(
         Vocabulary size.
     with_spans (Callable):
         Callback that constructs a span generator model.
+    piece_encoder (Model)
+        The piece encoder to segment input tokens.
     attention_probs_dropout_prob (float):
         Dropout probabilty of the self-attention layers.
     hidden_act (str):
@@ -312,8 +310,6 @@ def build_camembert_transformer_model_v1(
     grad_scaler_config (dict):
         Configuration passed to the PyTorch gradient scaler.
     """
-    piece_adapter = build_camembert_adapter()
-
     config = RobertaConfig(
         hidden_width=hidden_width,
         intermediate_width=intermediate_width,
@@ -338,12 +334,9 @@ def build_camembert_transformer_model_v1(
         encoder = RobertaEncoder(config)
         transformer = _pytorch_encoder(encoder)
 
-    piece_encoder = build_sentencepiece_encoder()
-
     return build_transformer_model_v1(
         with_spans=with_spans,
         piece_encoder=piece_encoder,
-        piece_adapter=piece_adapter,
         transformer=transformer,
     )
 
@@ -355,6 +348,7 @@ def build_roberta_transformer_model_v1(
         [TorchTransformerModelT],
         SpanExtractorModelT,
     ],
+    piece_encoder: Tok2PiecesModelT,
     attention_probs_dropout_prob: float = 0.1,
     hidden_act: str = "gelu",
     hidden_dropout_prob: float = 0.1,
@@ -377,6 +371,8 @@ def build_roberta_transformer_model_v1(
         Vocabulary size.
     with_spans (Callable):
         Callback that constructs a span generator model.
+    piece_encoder (Model)
+        The piece encoder to segment input tokens.
     attention_probs_dropout_prob (float):
         Dropout probabilty of the self-attention layers.
     hidden_act (str):
@@ -438,8 +434,6 @@ def build_roberta_transformer_model_v1(
             grad_scaler_config=grad_scaler_config,
         )
 
-    piece_encoder = build_byte_bpe_encoder()
-
     return build_transformer_model_v1(
         with_spans=with_spans,
         piece_encoder=piece_encoder,
@@ -454,6 +448,7 @@ def build_xlmr_transformer_model_v1(
         [TorchTransformerModelT],
         SpanExtractorModelT,
     ],
+    piece_encoder: Tok2PiecesModelT,
     attention_probs_dropout_prob: float = 0.1,
     hidden_act: str = "gelu",
     hidden_dropout_prob: float = 0.1,
@@ -476,6 +471,8 @@ def build_xlmr_transformer_model_v1(
         Vocabulary size.
     with_spans (Callable):
         Callback that constructs a span generator model.
+    piece_encoder (Model)
+        The piece encoder to segment input tokens.
     attention_probs_dropout_prob (float):
         Dropout probabilty of the self-attention layers.
     hidden_act (str):
@@ -509,8 +506,6 @@ def build_xlmr_transformer_model_v1(
     grad_scaler_config (dict):
         Configuration passed to the PyTorch gradient scaler.
     """
-    piece_adapter = build_xlmr_adapter()
-
     config = RobertaConfig(
         hidden_width=hidden_width,
         intermediate_width=intermediate_width,
@@ -539,12 +534,9 @@ def build_xlmr_transformer_model_v1(
             grad_scaler_config=grad_scaler_config,
         )
 
-    piece_encoder = build_sentencepiece_encoder()
-
     return build_transformer_model_v1(
         with_spans=with_spans,
         piece_encoder=piece_encoder,
-        piece_adapter=piece_adapter,
         transformer=transformer,
     )
 
@@ -557,27 +549,14 @@ def build_transformer_model_v1(
     ],
     transformer: TorchTransformerModelT,
     piece_encoder: Tok2PiecesModelT,
-    piece_adapter: Optional[PieceAdapterModelT] = None,
 ) -> TransformerModelT:
     # FIXME: do we want to make `remove_bos_eos` configurable as well or
     #        is it always the same post-processing?
-    if piece_adapter:
-        layers = [
-            with_non_ws_tokens(
-                chain(
-                    piece_encoder,
-                    piece_adapter,
-                    with_spans(transformer),
-                    remove_bos_eos(),
-                )
-            )
-        ]
-    else:
-        layers = [
-            with_non_ws_tokens(
-                chain(piece_encoder, with_spans(transformer), remove_bos_eos())
-            )
-        ]
+    layers = [
+        with_non_ws_tokens(
+            chain(piece_encoder, with_spans(transformer), remove_bos_eos())
+        )
+    ]
     refs = {
         "piece_encoder": piece_encoder,
         "transformer": transformer,
@@ -624,7 +603,7 @@ def _pytorch_encoder(
     grad_scaler_config: dict = SimpleFrozenDict(),
 ) -> TorchTransformerModelT:
     if isinstance(grad_scaler_config, SimpleFrozenDict):
-        # Crate a new, mutable dict instance.
+        # Create a new, mutable dict instance.
         grad_scaler_config = {}
 
     if "enabled" not in grad_scaler_config:
