@@ -27,12 +27,9 @@ def build_hf_encoder_loader_v1(
         if not has_hf_transformers:
             raise ValueError("requires huggingface transformers")
 
-        global transformers
-        from transformers import AutoModel
-
         encoder = model.shims[0]._model
 
-        hf_model = AutoModel.from_pretrained(name, revision=revision)
+        hf_model = transformers.AutoModel.from_pretrained(name, revision=revision)
         params = convert_hf_pretrained_model_parameters(hf_model)
         encoder.load_state_dict(params)
 
